==> peewee1.0.0.zip: peewee/framework/FrontController.class.php <==
<?php
require_once('lib/Smarty/Smarty.class.php');
require_once("config/action.require.config.php");

/**
 * եȥȥ顼饹<br>
 * ٤ƤΥꥯȤꡢ륯饹
 *
 * @package    peewee.framework
 * @author     rds <tk@rasign.jp>
 * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
 * @version    Release: 1.0.0
 * @link       http://peewee.rasign.jp/
 */
class FrontController{

    /**
     * ¹ԥ᥽å
     *
     * @param $target ̾
     * @param $request ꥯȥѥ᡼
     * @access public
     * @exception Exception 顼ȯ㳰
     */
	public function execute($target, $request){
		if(empty($target)){
			throw new Exception("You must enter a value for target parameter");
		}

		$smarty = new Smarty();
		$smarty->template_dir = "pages";
		$smarty->compile_dir = "lib/templates_c";
		$smarty->config_dir = "config";
		$smarty->cache_dir = "cache";

		if(class_exists($target)){
			$action = new $target();
			$methods = get_class_methods($action);
			if(!in_array("execute", $methods)){
				throw new Exception("execute method not found.");
			}

			$requestParameters = $request;
			$classVariables = array_keys(get_class_vars(get_class($action)));
			foreach($requestParameters as $key => $value){
				if(in_array($key, $classVariables)){
					$action->$key = $value;
				}
			}

			$action->execute();

			if(!empty($action->errors)){
				$smarty->assign("errors", $action->errors);
			}else{
				$array = get_class_vars(get_class($action));
				foreach ($array as $key => $tmp) {
					$smarty->assign($key, $action->$key);
				}
			}
		}

		// ե뤬ʤФ
		//if(true){
		//	$smarty->display("404.html");
		//}

		$smarty->display($target . '.html');
	}
}
?>

==> peewee1.1.0.zip: peewee/framework/FrontController.class.php <==
<?php
require_once('lib/Smarty/Smarty.class.php');
require_once("work/action.require.config.php");

/**
 * եȥȥ顼饹<br>
 * ٤ƤΥꥯȤꡢ륯饹
 *
 * @package    peewee.framework
 * @author     rds <tk@rasign.jp>
 * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
 * @version    Release: 1.0.0
 * @link       http://peewee.rasign.jp/
 */
class FrontController{

    /**
     * ¹ԥ᥽å
     *
     * @param $target ̾
     * @param $request ꥯȥѥ᡼
     * @access public
     * @exception Exception 顼ȯ㳰
     */
	public function execute($target, $request){
		if(empty($target)){
			throw new Exception("You must enter a value for target parameter");
		}

		$smarty = new Smarty();
		$smarty->template_dir = "pages";
		$smarty->compile_dir = "lib/templates_c";
		$smarty->config_dir = "config";
		$smarty->cache_dir = "cache";

		if(class_exists($target)){
			$action = new $target();
			$methods = get_class_methods($action);
			if(!in_array("execute", $methods)){
				throw new Exception("execute method not found.");
			}

			$requestParameters = $request;
			$classVariables = array_keys(get_class_vars(get_class($action)));
			foreach($requestParameters as $requestKey => $requestValue){
				if(in_array($requestKey, $classVariables)){
					$action->$requestKey = $requestValue;
				}
			}

			$action->execute();

			if(!empty($action->errors)){
				$smarty->assign("errors", $action->errors);
			}else{
				$array = get_class_vars(get_class($action));
				foreach ($array as $key => $tmp) {
					$smarty->assign($key, $action->$key);
				}
			}
		}

		// TODO
		// ե뤬ʤФ
		//if(true){
		//	$smarty->display("404.html");
		//}

		$smarty->display($target . '.html');
	}
}
?>
